labeltools.label_leaves_in_expr_with_melodic_chromatic_intervals
================================================================

.. autofunction:: abjad.tools.labeltools.label_leaves_in_expr_with_melodic_chromatic_intervals.label_leaves_in_expr_with_melodic_chromatic_intervals
   :noindex:
